@@ -10,7 +10,7 @@
 
 #include "openprojectpage.h"
 
-#include <QHBoxLayout>
+#include <QVBoxLayout>
 
 #include <kio_version.h>
 #include <KDirOperator>
@@ -29,7 +29,8 @@ OpenProjectPage::OpenProjectPage( const QUrl& startUrl, const QStringList& filte
     QWidget* parent )
         : QWidget( parent )
 {
-    auto* layout = new QHBoxLayout( this );
+    auto* layout = new QVBoxLayout( this );
+    layout->setContentsMargins(0, 0, 0, 0);
 
     fileWidget = new KFileWidget( startUrl, this);
 
