@@ -29,11 +29,22 @@
 #include <QProcess>
 #include <KLocalizedString>
 
-static const QVector<QString> args = {
-    QLatin1String("--help-command"), QLatin1String("--help-variable"), QLatin1String("--help-module"), QLatin1String("--help-property"), QLatin1String("--help-policy"), QString()
+#include <array>
+
+static const std::array<QString, 6> args = {
+    QStringLiteral("--help-command"),
+    QStringLiteral("--help-variable"),
+    QStringLiteral("--help-module"),
+    QStringLiteral("--help-property"),
+    QStringLiteral("--help-policy"),
+    QString(),
 };
-static QString modules [] = {
-    i18n("Commands"), i18n("Variables"), i18n("Modules"), i18n("Properties"), i18n("Policies")
+static const std::array<QString, 5> modules = {
+    i18n("Commands"),
+    i18n("Variables"),
+    i18n("Modules"),
+    i18n("Properties"),
+    i18n("Policies"),
 };
 
 CMakeCommandsContents::CMakeCommandsContents(QObject* parent)
@@ -97,7 +108,7 @@ QString CMakeCommandsContents::descriptionForIdentifier(const QString& id, CMake
     QString desc;
     if(args[t].size() != 0) {
         desc = CMake::executeProcess(CMakeBuilderSettings::self()->cmakeExecutable().toLocalFile(), { args[t], id.simplified() });
-        desc = desc.remove(QStringLiteral(":ref:"));
+        desc.remove(QLatin1String(":ref:"));
 
         const QString rst2html = QStandardPaths::findExecutable(QStringLiteral("rst2html"));
         if (rst2html.isEmpty()) {
