@@ -457,7 +457,7 @@ PathResolutionResult MakeFileResolver::resolveIncludePathInternal(const QString&
     QRegExp makeRx(QStringLiteral("\\bmake\\s"));
     int offset = 0;
     while ((offset = makeRx.indexIn(firstLine, offset)) != -1) {
-      QString prefix = firstLine.left(offset).trimmed();
+      QString prefix = firstLine.leftRef(offset).trimmed().toString();
       if (prefix.endsWith(QLatin1String("&&")) || prefix.endsWith(QLatin1Char(';')) || prefix.isEmpty()) {
         QString newWorkingDirectory = workingDirectory;
         ///Extract the new working-directory
@@ -542,8 +542,7 @@ static QString unescape(const QStringRef& input)
   QString output;
   output.reserve(input.length());
   bool isEscaped = false;
-  for (auto it = input.data(), end = it + input.length(); it != end; ++it) {
-    QChar c = *it;
+  for (const QChar c : input) {
     if (!isEscaped && c == QLatin1Char('\\')) {
       isEscaped = true;
     } else {
@@ -576,7 +575,7 @@ PathResolutionResult MakeFileResolver::processOutput(const QString& fullOutput,
       if (QDir::isRelativePath(path))
         path = workingDirectory + QLatin1Char('/') + path;
       const auto& internedPath = internPath(path);
-      const auto& type = match.captured(1);
+      const auto type = match.capturedRef(1);
       const auto isFramework = type.startsWith(QLatin1String("-iframework"))
         || type.startsWith(QLatin1String("-F"));
       if (isFramework) {
