@@ -34,13 +34,13 @@
 #include <sublime/view.h>
 #include <sublime/document.h>
 #include <sublime/mainwindow.h>
+#include <sublime/message.h>
 
 #include <QFileInfo>
 #include <QMenu>
 #include <QJsonObject>
 #include <QJsonArray>
 
-#include <KMessageBox>
 #include <KLocalizedString>
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
@@ -221,13 +221,16 @@ void PatchReviewToolView::showEditDialog() {
 
 #ifdef WITH_PURPOSE
     m_exportMenu = new Purpose::Menu(this);
-    connect(m_exportMenu, &Purpose::Menu::finished, this, [](const QJsonObject &output, int error, const QString &message) {
+    connect(m_exportMenu, &Purpose::Menu::finished, this, [](const QJsonObject &output, int error, const QString &errorMessage) {
+        Sublime::Message* message;
         if (error==0) {
-            KMessageBox::information(nullptr, i18n("<qt>You can find the new request at:<br /><a href='%1'>%1</a> </qt>", output[QLatin1String("url")].toString()),
-                                    QString(), QString(), KMessageBox::AllowLink);
+            const QString messageText = i18n("<qt>You can find the new request at:<br /><a href='%1'>%1</a> </qt>", output[QLatin1String("url")].toString());
+            message = new Sublime::Message(messageText, Sublime::Message::Information);
         } else {
-            QMessageBox::warning(nullptr, i18n("Error exporting"), i18n("Couldn't export the patch.\n%1", message));
+            const QString messageText = i18n("Couldn't export the patch.\n%1", errorMessage);
+            message = new Sublime::Message(messageText, Sublime::Message::Error);
         }
+        ICore::self()->uiController()->postMessage(message);
     });
     // set the model input parameters to avoid terminal warnings
     m_exportMenu->model()->setInputData(QJsonObject {
@@ -308,7 +311,7 @@ void PatchReviewToolView::seekFile(bool forwards)
 {
     if(!m_plugin->patch())
         return;
-    QList<QUrl> checkedUrls = m_fileModel->checkedUrls();
+    const QList<QUrl> checkedUrls = m_fileModel->checkedUrls();
     QList<QUrl> allUrls = m_fileModel->urls();
     IDocument* current = ICore::self()->documentController()->activeDocument();
     if(!current || checkedUrls.empty())
@@ -332,7 +335,11 @@ void PatchReviewToolView::seekFile(bool forwards)
     }
     else
     {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+        QSet<QUrl> checkedUrlsSet(checkedUrls.begin(), checkedUrls.end());
+#else
         QSet<QUrl> checkedUrlsSet( checkedUrls.toSet() );
+#endif
         for(int offset = 1; offset < allUrls.size(); ++offset)
         {
             int pos;
@@ -486,14 +493,13 @@ void PatchReviewToolView::kompareModelChanged() {
     const Diff2::DiffModelList* models = m_plugin->modelList()->models();
     if( models )
     {
-        Diff2::DiffModelList::const_iterator it = models->constBegin();
-        for(; it != models->constEnd(); ++it ) {
-            Diff2::DifferenceList * diffs = ( *it )->differences();
+        for (auto* model : *models) {
+            const Diff2::DifferenceList* diffs = model->differences();
             int cnt = 0;
             if ( diffs )
                 cnt = diffs->count();
 
-            const QUrl file = m_plugin->urlForFileModel( *it );
+            const QUrl file = m_plugin->urlForFileModel(model);
             if( file.isLocalFile() && !QFileInfo( file.toLocalFile() ).isReadable() )
                 continue;
 
